@@ -70,18 +70,18 @@
 #' - Unlike AAD v1.0, AAD v2.0 does not return an ID token by default. To get a token, specify `openid` as a scope. On the other hand it _does_ refresh the ID token, so bypassing the cache is not needed. It's recommended to use AAD v2.0 if you only want an ID token.
 #'
 #' @section Caching:
-#' AzureAuth caches tokens based on all the inputs to `get_azure_token` as listed above. Tokens are cached in a custom, user-specific directory, created with the rappdirs package. On recent Windows versions, this will usually be in the location `C:\\Users\\(username)\\AppData\\Local\\AzureR`. On Linux, it will be in `~/.config/AzureR`, and on MacOS, it will be in `~/Library/Application Support/AzureR`. Note that a single directory is used for all tokens, and the working directory is not touched (which significantly lessens the risk of accidentally introducing cached tokens into source control).
+#' AzureAuth caches tokens based on all the inputs to `get_azure_token` as listed above. Tokens are cached in a custom, user-specific directory, created with the rappdirs package. On recent Windows versions, this will usually be in the location `C:\\Users\\(username)\\AppData\\Local\\AzureR`. On Linux, it will be in `~/.config/AzureR`, and on MacOS, it will be in `~/Library/Application Support/AzureR`. Alternatively, you can specify the location of the directory in the environment variable `R_AZURE_DATA_DIR`. Note that a single directory is used for all tokens, and the working directory is not touched (which significantly lessens the risk of accidentally introducing cached tokens into source control).
 #'
 #' To list all cached tokens on disk, use `list_azure_tokens`. This returns a list of token objects, named according to their MD5 hashes.
 #'
 #' To delete a cached token, use `delete_azure_token`. This takes the same inputs as `get_azure_token`, or you can specify the MD5 hash directly in the `hash` argument.
 #'
-#' To delete _all_ cached tokens, use `clean_token_directory`.
+#' To delete all files in the caching directory, use `clean_token_directory`.
 #'
 #' @section Refreshing:
 #' A token object can be refreshed by calling its `refresh()` method. If the token's credentials contain a refresh token, this is used; otherwise a new access token is obtained by reauthenticating.
 #'
-#' Note that in AAD, a refresh token can be used to obtain an access token for any resource or scope that you have permissions for. Thus, for example, you could use a refresh token issued on a request for `https://management.azure.com` to obtain a new access token for `https://graph.microsoft.com` (assuming you've been granted permission).
+#' Note that in AAD, a refresh token can be used to obtain an access token for any resource or scope that you have permissions for. Thus, for example, you could use a refresh token issued on a request for Azure Resource Manager (`https://management.azure.com/`) to obtain a new access token for Microsoft Graph (`https://graph.microsoft.com/`).
 #'
 #' To obtain an access token for a new resource, change the object's `resource` (for an AAD v1.0 token) or `scope` field (for an AAD v2.0 token) before calling `refresh()`. If you _also_ want to retain the token for the old resource, you should call the `clone()` method first to create a copy. See the examples below.
 #'
@@ -90,6 +90,8 @@
 #'
 #' For `list_azure_tokens`, a list of such objects retrieved from disk.
 #'
+#' The actual credentials that are returned from the authorization endpoint can be found in the `credentials` field, the same as with a `httr::Token` object. The access token (if present) will be `credentials$access_token`, and the ID token (if present) will be `credentials$id_token`. Use these if you are manually constructing a HTTP request and need to insert an "Authorization" header, for example.
+#'
 #' @seealso
 #' [AzureToken], [httr::oauth2.0_token], [httr::Token], [cert_assertion],
 #' [build_authorization_uri], [get_device_creds]
@@ -211,6 +213,12 @@
 #' tok2$scope <- c("https://anotherresource/.default", "offline_access")
 #' tok2$refresh()
 #'
+#'
+#' # manually adding auth header for a HTTP request
+#' tok <- get_azure_token("https://myresource", "mytenant", "app_id")
+#' header <- httr::add_headers(Authorization=paste("Bearer", tok$credentials$access_token))
+#' httr::GET("https://myresource/path/for/call", header, ...)
+#'
 #' }
 #' @export
 get_azure_token <- function(resource, tenant, app, password=NULL, username=NULL, certificate=NULL, auth_type=NULL,
@@ -289,10 +297,10 @@ clean_token_directory <- function(confirm=TRUE)
         return(invisible(NULL))
 
     if(confirm && interactive() &&
-       !get_confirmation("Do you really want to delete ALL saved Azure Active Directory tokens?", FALSE))
+       !get_confirmation("Do you really want to remove all files in the AzureR token directory?", FALSE))
             return(invisible(NULL))
 
-    toks <- dir(AzureR_dir(), pattern="^[0-9a-f]{32}$", full.names=TRUE)
+    toks <- dir(AzureR_dir(), full.names=TRUE)
     file.remove(toks)
     invisible(NULL)
 }
